# encoding: UTF-8
require 'thor'
require_relative 'writer'
include Minireq::Gitbook

module Minireq
  module Gitbook

    class Cli < Thor
      include Thor::Actions

      map %w[--version -v] => :__print_version

      no_commands {

        def __under_construction
          puts "UNDER_CONSTRUCTION"
        end

        def __exec_asynchronously(command)
          pid = spawn(command)
          Process.detach(pid)
        end
      }

      desc "--version, -v", "Print the version"
      def __print_version
        puts "minireq-gitbook #{Minireq::Gitbook::VERSION}"
      end

      # minireq-gitbook build
      desc "build [TARGET]", "Build GitBook project in [TARGET='book'] folder"
      def build(target = "book")
        # TODO check if Dir.pws is Minireq project folder
        `minireq doc`
        Writer.write(target)
        FileUtils.copy_entry "docs/assets", "#{target}/assets"
        puts "GitBook project is created in folder:\n'#{target}'"
      end

      desc "deploy [TARGET]", "Pull, build and serve book in TARGET [book] folder"
      method_option :port, aliases: "-p", type: :numeric, desc: "port of 'gitbook' serve command"
      method_option :lrport, aliases: "-l", type: :numeric, desc: "life reload  port of 'gitbook serve' command"
      def deploy(target = "book")
        `git pull`
        `minireq-gitbook build #{target}`
        params = ""
        params << " --port #{options[:port]}" if options[:port]
        params << " --lrport #{options[:lrport]}" if options[:lrport]
        pid = spawn("gitbook serve #{target}#{params}")
        Process.detach(pid)
      end

    end
  end
end

=begin
@cmd /k "command1&command2"
start cmd.exe @cmd /k "Command"

c:\Users\n.voynov\Documents\ruby\minireq_promo\book>gitbook help
    build [book] [output]        build a book
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)
        --format         Format to build to (Default is website; Values are website, json, ebook)
        --timing         Print timing debug information (Default is false)

    serve [book] [output]        serve the book as a website for testing
        --port   Port for server to listen on (Default is 4000)
        --lrport         Port for livereload server to listen on (Default is 35729)
        --watch          Enable file watcher and live reloading (Default is true)
        --live   Enable live reloading (Default is true)
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)
        --format         Format to build to (Default is website; Values are website, json, ebook)

    install [book]       install all plugins dependencies
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)

    parse [book]         parse and print debug information about a book
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)

    init [book]          setup and create files for chapters
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)

    pdf [book] [output]          build a book into an ebook file
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)

    epub [book] [output]         build a book into an ebook file
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)

    mobi [book] [output]         build a book into an ebook file
        --log    Minimum log level to display (Default is info; Values are debug, info, warn, error, disabled)
=end
