# encoding: UTF-8
require 'unicode'
require_relative 'node'

module Minireq
  module Gitbook

    class Summary

      def self.write(node, document_file, summary_file)
        writer = Summary.new(node, document_file, summary_file)
        writer.summary
      end

      def initialize(node, document_file, summary_file)
        @node  = node
        @document_file = document_file
        @summary_file = summary_file
      end

      def summary
        content_file = File.basename(@document_file)
        File.open(@summary_file, 'w') do |f|
          f.write "# Summary\n"
          @node.visit do |n|
            next if n.level.eql?(0)
            pre = "  "*(n.level - 1)
            url = get_url(n.header)
            f.write "#{pre}* [#{n.header}](#{content_file}##{url})\n"
          end
        end
      end

      def self.get_url(title)
        url = Unicode::downcase(title)
        url
          .gsub(/[^A-Za-z0-9А-Яа-я\s]/, '')
          .gsub(/\s/, '-')
          .gsub(/--/, '-')
          .gsub(/--/, '-')
          .strip
      end
    end

=begin
{% set softwareVersion = "1.0.0" %}
Current version is {{ softwareVersion }}.
[Download it](website.com/download/{{ softwareVersion }})
=end
  end
end
