# encoding: UTF-8
require 'minireq'
require_relative 'node.rb'
require_relative 'reader.rb'
require_relative 'summary.rb'

module Minireq
  module Gitbook

=begin
    Writer is a class for GitBook folder creation
=end
    class Writer

      def self.write(gitbook_folder)
        writer = Writer.new(gitbook_folder)
        writer.create_gitbook
      end

      def create_gitbook
        init_gitbook
        write_document
        write_summary
      end

      private

        REQDOC = 'docs/requirements.md'

        # TODO extract git tag from minireq repository
        BOOKJN = %({
  "title": "Software Requirements Specification",
  "gitbook": "3.1.1",
  "plugins": [
      "-search"
  ]
}
)

        README = %(# Introduction\nThis book was created by [Minireq-gitbook](https://github.com/nvoynov/minireq-gitbook) plugin from [Minireq](https://github.com/nvoynov/minireq) requirements repository.\n\nTODO: provide Minreq information like project name, authors, etc.\n\nTODO: You can download this document as ebook __TBD__ ([pdf](pdf), [epub](epub), [mobi](mobi))
        )

        def initialize(gitbook_folder)
          @gitbook_folder = gitbook_folder
        end

        def init_gitbook
          Dir.mkdir(@gitbook_folder) unless Dir.exist?(@gitbook_folder)
          Dir.chdir(@gitbook_folder) do
            File.write('book.json', BOOKJN)
            File.write('README.md', README)
          end
        end

        # we are in Minireq project folder!
        # TODO ask Mnireq about output document?
        def write_summary
          # build minireq requirememnt.md
          `minireq doc`
          # parse and write summary
          txt = File.read(REQDOC)
          doc = Reader.read(txt)
          summary_file = @gitbook_folder + '/SUMMARY.md'
          Summary.write(doc, REQDOC, summary_file)
        end

        def write_document
          out = @gitbook_folder + '/' + File.basename(REQDOC)
          File.open(out, 'w') do |f|
            File.foreach(REQDOC){|l| f.write escape(l)}
          end
        end

        def escape(text)
          text
            .gsub(/{{/, "{% raw %} {{ {% endraw %}")
            .gsub(/}}/, "{% raw %} }} {% endraw %}")
        end

    end

  end
end
